==> waldur_api_client-0.1.0-py3-none-any.whl: waldur_api_client/models/screenshot_request.py <==
from io import BytesIO
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, File, Unset

T = TypeVar("T", bound="ScreenshotRequest")


@_attrs_define
class ScreenshotRequest:
    """
    Attributes:
        name (str):
        image (File):
        offering (str):
        description (Union[Unset, str]):
    """

    name: str
    image: File
    offering: str
    description: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        image = self.image.to_tuple()

        offering = self.offering

        description = self.description

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "image": image,
                "offering": offering,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        image = File(payload=BytesIO(d.pop("image")))

        offering = d.pop("offering")

        description = d.pop("description", UNSET)

        screenshot_request = cls(
            name=name,
            image=image,
            offering=offering,
            description=description,
        )

        screenshot_request.additional_properties = d
        return screenshot_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> waldur_api_client-7.7.0-py3-none-any.whl: waldur_api_client/models/screenshot_request.py <==
from collections.abc import Mapping
from io import BytesIO
from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, File, Unset

T = TypeVar("T", bound="ScreenshotRequest")


@_attrs_define
class ScreenshotRequest:
    """
    Attributes:
        name (str):
        image (File):
        offering (str):
        description (Union[Unset, str]):
    """

    name: str
    image: File
    offering: str
    description: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        image = self.image.to_tuple()

        offering = self.offering

        description = self.description

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "image": image,
                "offering": offering,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        image = File(payload=BytesIO(d.pop("image")))

        offering = d.pop("offering")

        description = d.pop("description", UNSET)

        screenshot_request = cls(
            name=name,
            image=image,
            offering=offering,
            description=description,
        )

        screenshot_request.additional_properties = d
        return screenshot_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
